@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3tables/S3Tables_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3tables/S3Tables_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Tables
-{
-namespace Model
-{
-  enum class SSEAlgorithm
-  {
-    NOT_SET,
-    AES256,
-    aws_kms
-  };
+namespace Aws {
+namespace S3Tables {
+namespace Model {
+enum class SSEAlgorithm { NOT_SET, AES256, aws_kms };
 
-namespace SSEAlgorithmMapper
-{
+namespace SSEAlgorithmMapper {
 AWS_S3TABLES_API SSEAlgorithm GetSSEAlgorithmForName(const Aws::String& name);
 
 AWS_S3TABLES_API Aws::String GetNameForSSEAlgorithm(SSEAlgorithm value);
-} // namespace SSEAlgorithmMapper
-} // namespace Model
-} // namespace S3Tables
-} // namespace Aws
+}  // namespace SSEAlgorithmMapper
+}  // namespace Model
+}  // namespace S3Tables
+}  // namespace Aws
